#!D:\bld\gdal-split_1595893984028\_h_env\python.exe
# EASY-INSTALL-SCRIPT: 'GDAL==3.1.2','gdal_polygonize.py'
__requires__ = 'GDAL==3.1.2'
__import__('pkg_resources').run_script('GDAL==3.1.2', 'gdal_polygonize.py')
